@@ -46,6 +46,8 @@ def fis_eda_categoric_graph(df_cat):
         df_cat[variable].value_counts().plot.barh(ax = ax[cada])
         ax[cada].set_title(variable, fontsize = 12, fontweight = "bold")
         ax[cada].tick_params(labelsize = 12)
+    plt.tight_layout()
+    plt.show()
         
 def fis_eda_continous_graph(df_cont,mode='density'):
     """
@@ -69,6 +71,8 @@ def fis_eda_continous_graph(df_cont,mode='density'):
             df_cont[variable].plot(ax = ax[cada])
         ax[cada].set_title(variable, fontsize = 12, fontweight = "bold")
         ax[cada].tick_params(labelsize = 12)
+    plt.tight_layout()
+    plt.show()
         
 
 def fis_preprocessing_strong_corr(df,lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
